<?php

namespace EPIC\GALLERY\Elements\Options;

use Jeg\Element\Elements\Elements_Option_Abstract;

abstract class GalleryOptionAbstract extends Elements_Option_Abstract {
	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return [ esc_html__( 'All Columns', 'epic-gallery' ) ];
	}

	public function get_category() {
		return esc_html__( 'EPIC - Gallery', 'epic-gallery' );
	}

	/**
	 * Set Option
	 */
	public function set_options() {
		$this->set_element_option();
	}

	public function set_element_option() {
		$this->options['gallery_title']       = [
			'type'        => 'text',
			'title'       => esc_html__( 'Gallery Title', 'epic-gallery' ),
			'description' => esc_html__( 'Insert title of your gallery.', 'epic-gallery' ),
			'segment'     => 'general'
		];
		$this->options['preview_slider_desc'] = [
			'type'    => 'checkbox',
			'title'   => esc_html__( 'Use Slider Zoom with Description', 'epic-gallery' ),
			'value'   => [ esc_html__( 'Enabling this option to have description when zoomed.', 'epic-gallery' ) => 'yes' ],
			'segment' => 'general',
		];

		$this->options['preview_slider_loader'] = [
			'type'        => 'select',
			'default'     => 'dot',
			'title'       => esc_html__( 'Preview Slider Loader Style', 'epic-gallery' ),
			'description' => esc_html__( 'Choose loader style that you want to use for gallery.', 'epic-gallery' ),
			'segment'     => 'general',
			'options'     => [
				'dot'    => esc_html__( 'Dot', 'epic-gallery' ),
				'circle' => esc_html__( 'Circle', 'epic-gallery' ),
				'square' => esc_html__( 'Square', 'epic-gallery' ),
			],
		];

		$this->options['slider_scheme'] = [
			'type'        => 'select',
			'default'     => epic_gallery_get_option( 'slider_scheme', 'dark' ),
			'title'       => esc_html__( 'Slider Scheme Style', 'epic-gallery' ),
			'description' => esc_html__( 'Choose slider scheme style that you want to use for the gallery.', 'epic-gallery' ),
			'segment'     => 'general',
			'options'     => [
				'dark'  => esc_html__( 'Dark', 'epic-gallery' ),
				'light' => esc_html__( 'Light', 'epic-gallery' ),
			],
		];

		$this->options['preview_slider_ads'] = [
			'type'    => 'checkbox',
			'title'   => esc_html__( 'Show Ads Wrapper', 'epic-gallery' ),
			'value'   => [ esc_html__( 'Enabling this option to have ads section when zoomed.', 'epic-gallery' ) => 'yes' ],
			'segment' => 'general',
		];

	}

	/**
	 * Set Segments
	 */
	public function set_segments() {
		$this->set_general_segment();
	}

	public function set_general_segment() {
		$this->segments['general'] = [
			'name'     => esc_html__( 'General', 'epic-gallery' ),
			'priority' => 10
		];
	}

}