<?php

namespace EPIC\GALLERY\Elements\Views;

use Jeg\Element\Elements\Elements_View_Abstract;

abstract class GalleryViewAbstract extends Elements_View_Abstract {

	public function render_gallery( $content, $attr ) {

		$zoom_script   = $attr['preview_slider_desc'] ? true : false;
		$native_zoom   = $zoom_script ? 'true' : 'false';
		$loader        = $attr['preview_slider_loader'];
		$show_ad       = $attr['preview_slider_ads'] ? true : false;
		$gallery_title = ! empty( $attr['gallery_title'] ) ? $attr['gallery_title'] : '';
		$scheme        = $attr['slider_scheme'] === 'light' ? 'slider_light' : '';


		$html5 = current_theme_supports( 'html5', 'gallery' );
		$atts  = [
			'itemtag'    => $html5 ? 'figure' : 'dl',
			'icontag'    => $html5 ? 'div' : 'dt',
			'captiontag' => $html5 ? 'figcaption' : 'dd',
			'link'       => '',
		];
		if ( $zoom_script !== 'disable' ) {
			$atts['link'] = 'file';
		}

		$preview_holder_content =
			"<div class=\"jeg_preview_media\">
                    <div class=\"jeg_preview_media_holder\">
                        <h3>{$gallery_title}</h3>
                        <div class=\"fullscreen-switch\">
                            <i class=\"fa\"></i>
                        </div>
                        <div class=\"jeg_preview_media_content\">
                            <div class=\"jeg_preview_media_content_holder_padding\">
                                <div class=\"jeg_preview_media_content_holder\"></div>
                            </div>
                            <div class=\"jeg_preview_media_content_navigation\">
                                <div class=\"prev\"></div>
                                <div class=\"next\"></div>
                            </div>
                            <div class='preview-slider-overlay'>
                                <div class='preloader_type preloader_{$loader}'>
                                    <div class=\"module-preloader jeg_preloader dot\">
                                        <span></span><span></span><span></span>
                                    </div>
                                    <div class=\"module-preloader jeg_preloader circle\">
                                        <div class=\"jeg_preloader_circle_outer\">
                                            <div class=\"jeg_preloader_circle_inner\"></div>
                                        </div>
                                    </div>
                                    <div class=\"module-preloader jeg_preloader square\">
                                        <div class=\"jeg-cube-grid\">
                                            <div class=\"jeg-cube jeg-cube1\"></div>
                                            <div class=\"jeg-cube jeg-cube2\"></div>
                                            <div class=\"jeg-cube jeg-cube3\"></div>
                                            <div class=\"jeg-cube jeg-cube4\"></div>
                                          </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class=\"jeg_preview_control\">
                            <div class=\"left_control\">
                                <div class=\"counter\"><span class=\"current\">1</span> " . jeg_return_translation( 'of', 'epic-gallery', 'of' ) . "  {$content['slider_size']}</div>
                                <div class=\"subtitle\"></div>
                            </div>
                            <div class=\"zoom\">
                                <span class=\"reduce\">-</span>
                                <span class=\"increase\">+</span>
                            </div>
                        </div>
                    </div>
                </div>

                <div class=\"jeg_preview_bottom_slider owl-carousel\">
                    {$content['image_slides']}
                </div>";

		$preview_ads_container = '';

		if ( $show_ad ) {
			$preview_ads_container =
				'<div class="jeg_preview_slider_ads">' . $this->render_ads( $attr ) . '</div>';
		}

		// script parameter
		$is_rtl         = is_rtl() ? 'true' : 'false';
		$image_sequence = wp_json_encode( $content['image_sequence'] );
		$max_zoom       = apply_filters( 'epic_gallery_max_zoom', 5 );
		$zoom_step      = apply_filters( 'epic_gallery_zoom_step', 40 );

		return "<div class=\"jeg_preview_slider {$scheme} {$this->unique_id}\" data-selector='{$this->unique_id}'>
                    <div class=\"jeg_preview_holder\">
                        {$preview_holder_content}
                    </div>
                    <div class=\"jeg_preview_description\">
                        {$preview_ads_container}
                        <div class=\"jeg_preview_description_wrapper\">
                        {$content['preview_description_content']}
                        </div>
                    </div>
                    <script>
                        var {$this->unique_id} = {
                            rtl: {$is_rtl},
                            native_zoom: {$native_zoom},
                            zoom_max: {$max_zoom},
                            zoom_step: {$zoom_step},
                            image_sequence: {$image_sequence}
                        };
                    </script>
                </div>";
	}

	public function render_ads( $attr ) {
		ob_start();
		do_action( 'epic_ad_render_epic_gallery_epic_gallery' );
		$ads_html = ob_get_contents();
		ob_end_clean();

		return "<div class='ads-wrapper'>" . $ads_html . "</div>";
	}

	/**
	 * @param $result
	 * @param $attr
	 */
	public function render_result_element( $result, $attr ) {
		// TODO: Implement render_result_element() method.
	}
}