<?php
/**
 * Get option for Gallery
 *
 * @param string $setting Setting name.
 * @param mixed $default Default option.
 *
 * @return mixed
 */
if ( ! function_exists( 'epic_gallery_get_option' ) ) {
	function epic_gallery_get_option( $setting, $default = null ) {
		$options = get_option( 'gallery_option', [] );
		$value   = $default;

		if ( isset( $options[ $setting ] ) ) {
			$value = $options[ $setting ];
		}

		return $value;
	}
}

/**
 * Check if Gallery Enabled
 *
 * @param $atts
 *
 * @return bool
 */
if ( ! function_exists( 'epic_gallery_is_enabled' ) ) {
	function epic_gallery_is_enabled( $atts ) {
		if ( $atts['epicslider'] ) {
			return true;
		}

		return epic_gallery_get_option( 'preview_slider_toggle', false );
	}
}

/**
 * Check if Gallery Description Enabled
 *
 * @param $atts
 *
 * @return bool|mixed
 */
if ( ! function_exists( 'epic_gallery_is_desc_enabled' ) ) {
	function epic_gallery_is_desc_enabled( $atts ) {
		if ( epic_gallery_is_enabled( $atts ) ) {
			if ( $atts['epicslider'] ) {
				return $atts['epicslider_zoom'];
			}

			return epic_gallery_get_option( 'preview_slider_desc', false );
		}

		return false;
	}
}

/**
 * Check if Gallery Description Enabled
 *
 * @param $atts
 *
 * @return bool
 */
if ( ! function_exists( 'epic_gallery_is_ads_enabled' ) ) {
	function epic_gallery_is_ads_enabled( $atts ) {
		if ( epic_gallery_is_enabled( $atts ) ) {
			if ( $atts['epicslider'] ) {
				return $atts['epicslider_ads'];
			}

			return epic_gallery_get_option( 'preview_slider_ads', false );
		}

		return false;
	}
}

if ( ! function_exists( 'epic_gallery_ads' ) ) {
	function epic_gallery_ads() {
		ob_start();
		do_action( 'epic_ad_render_epic_gallery_epic_gallery' );
		$ads_html = ob_get_contents();
		ob_end_clean();
		
		return "<div class='ads-wrapper'>" . $ads_html . '</div>';
	}
}

/**
 * @return mixed
 */
if ( ! function_exists( 'epic_gallery_popup_script' ) ) {
	add_filter( 'epic_gallery_single_popup_script', 'epic_gallery_popup_script' );
	function epic_gallery_popup_script() {
		return epic_gallery_get_option( 'single_popup_script', 'magnific' );
	}
}


/** Print Translation */

if ( ! function_exists( 'jeg_print_translation' ) ) {
	function jeg_print_translation( $string, $domain, $name ) {
		do_action( 'jeg_return_translation', $string, $domain, $name );
	}
}


if ( ! function_exists( 'jeg_print_main_translation' ) ) {
	add_action( 'jeg_print_translation', 'jeg_print_main_translation', 10, 2 );

	function jeg_print_main_translation( $string, $domain ) {
		call_user_func_array( 'esc_html_e', [ $string, $domain ] );
	}
}

/** Return Translation */

if ( ! function_exists( 'jeg_return_translation' ) ) {
	function jeg_return_translation( $string, $domain, $name, $escape = true ) {
		return apply_filters( 'jeg_return_translation', $string, $domain, $name, $escape );
	}
}

if ( ! function_exists( 'jeg_return_main_translation' ) ) {
	add_filter( 'jeg_return_translation', 'jeg_return_main_translation', 10, 4 );

	function jeg_return_main_translation( $string, $domain, $name, $escape = true ) {
		if ( $escape ) {
			return call_user_func_array( 'esc_html__', [ $string, $domain ] );
		}

		return call_user_func_array( '__', [ $string, $domain ] );

	}
}
